@@ -23,6 +23,16 @@ def _find_dim(grp, dimname):
                 raise ValueError("cannot find dimension %s in this group or parent groups" % dimname)
     return dim
 
+def _walk_grps(topgrp):
+    """Iterate through all (sub-) groups of topgrp, similar to os.walktree.
+
+    """
+    grps = topgrp.groups.values()
+    yield grps
+    for grp in topgrp.groups.values():
+        for children in _walk_grps(grp):
+            yield children
+
 def _quantize(data,least_significant_digit):
     """
 quantize data to improve compression. data is quantized using
@@ -274,7 +284,7 @@ Boolean array must have the same shape as the data along this dimension."""
                 else:
                     length = e.start+datashape[i]
             else:
-                if unlim and datashape == ():
+                if unlim and datashape == () and len(dim) == 0:
                     # writing scalar along unlimited dimension using slicing
                     # syntax (var[:] = 1, when var.shape = ())
                     length = 1
